<?php
/**
*
* @package phpBB Extension - Forum Goal
* @copyright (c) 2016 Stoker
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\forumgoal\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	protected $template;

	protected $config;

	protected $db;

	protected $user;

	public function __construct(\phpbb\template\template $template, \phpbb\config\config $config, \phpbb\db\driver\driver_interface $db, \phpbb\user $user, \phpbb\controller\helper $helper, \phpbb\collapsiblecategories\operator\operator $operator = null)
	{
		$this->template = $template;
		$this->config = $config;
		$this->db = $db;
		$this->user = $user;
		$this->helper = $helper;
		$this->operator = $operator;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.index_modify_page_title'	=> 'index_modify_page_title',
		);
	}

	public function index_modify_page_title($event)
	{
		$this->user->add_lang_ext('stoker/forumgoal', 'common');
		
		if ($this->operator !== null)
		{
			$fid = 'foo_forumgoal'; // can be any unique string to identify your extension's collapsible element
			$this->template->assign_vars(array(
				'S_FOO_FORUMGOAL_HIDDEN' => in_array($fid, $this->operator->get_user_categories()),
				'U_FOO_FORUMGOAL_COLLAPSE_URL' => $this->helper->route('phpbb_collapsiblecategories_main_controller', array(
					'forum_id' => $fid,
					'hash' => generate_link_hash("collapsible_$fid")))
			));
		}
		
		$this->template->assign_var('FORUMGOALS_DISPLAY', $this->config['forum_goals_display']);
		$this->template->assign_var('FORUMGOAL_ENABLE', $this->config['forumgoal_enable']);

			if (!empty($this->config['forum_goals_posts_enable']) && $this->config['forum_goals_posts'] > 0)
			{
				$total_posts = $this->config['num_posts'];
				$forum_goals_posts_percent = ($total_posts * 100) / $this->config['forum_goals_posts'];
				$forum_goals_posts_rest = $this->config['forum_goals_posts'] - $total_posts;
				$this->template->assign_vars(array(
					'FPG_ENABLE'					=> $this->config['forum_goals_posts_enable'],
					'FORUM_POST_GOAL'				=> $this->config['forum_goals_posts'],
					'FORUM_POST_GOAL_TOTAL'			=> $total_posts,
					'FORUM_POST_PERCENT'			=> round($forum_goals_posts_percent),
					'FORUM_POST_REST'				=> $forum_goals_posts_rest,
				 ));
			}

			if (!empty($this->config['forum_goals_topics_enable']) && $this->config['forum_goals_topics'] > 0)
			{
				$total_topics = $this->config['num_topics'];
				$forum_goals_topics_percent = ($total_topics * 100) / $this->config['forum_goals_topics'];
				$forum_goals_topics_rest = $this->config['forum_goals_topics'] - $total_topics;
				$this->template->assign_vars(array(
					'FTG_ENABLE'					=> $this->config['forum_goals_topics_enable'],
					'FORUM_TOPIC_GOAL'				=> $this->config['forum_goals_topics'],
					'FORUM_TOPIC_GOAL_TOTAL'		=> $total_topics,
					'FORUM_TOPIC_PERCENT'			=> round($forum_goals_topics_percent),
					'FORUM_TOPIC_REST'				=> $forum_goals_topics_rest,
				));
			}

			if (!empty($this->config['forum_goals_users_enable']) && $this->config['forum_goals_users'] > 0)
			{
				$total_users = $this->config['num_users'];
				$forum_goals_users_percent = ($total_users * 100) / $this->config['forum_goals_users'];
				$forum_goals_users_rest = $this->config['forum_goals_users'] - $total_users;
				$this->template->assign_vars(array(
					'FUG_ENABLE'					=> $this->config['forum_goals_users_enable'],
					'FORUM_USER_GOAL'				=> $this->config['forum_goals_users'],
					'FORUM_USER_GOAL_TOTAL'			=> $total_users,
					'FORUM_USER_PERCENT'			=> round($forum_goals_users_percent),
					'FORUM_USER_REST'				=> $forum_goals_users_rest,
				));
			}

			if (!empty($this->config['forum_goals_files_enable']) && $this->config['forum_goals_files'] > 0)
			{
				$total_files	= $this->config['num_files'];
				$forum_goals_files_percent = ($total_files * 100) / $this->config['forum_goals_files'];
				$forum_goals_files_rest = $this->config['forum_goals_files'] - $total_files;
				$this->template->assign_vars(array(
					'FFG_ENABLE'					=> $this->config['forum_goals_files_enable'],
					'TOTAL_FILES'					=> $total_files,
					'FORUM_FILES_GOAL'				=> $this->config['forum_goals_files'],
					'FORUM_FILES_PERCENT'			=> round($forum_goals_files_percent),
					'FORUM_FILES_REST'				=> $forum_goals_files_rest,
				));
			}

			if (!empty($this->config['forum_goals_views_enable']) && $this->config['forum_goals_views'] > 0)
			{
				$sql = 'SELECT SUM(topic_views) AS count
					FROM ' . TOPICS_TABLE . '
					WHERE topic_posts_unapproved = 0';
				$result = $this->db->sql_query($sql);
				$total_views = (int) $this->db->sql_fetchfield('count');

				$forum_goals_views_percent = ($total_views * 100) / $this->config['forum_goals_views'];
				$forum_goals_views_rest = $this->config['forum_goals_views'] - $total_views;
				$this->template->assign_vars(array(
					'FTVG_ENABLE'					=> $this->config['forum_goals_views_enable'],
					'TOTAL_VIEWS'					=> $total_views,
					'FORUM_VIEW_GOAL'				=> $this->config['forum_goals_views'],
					'FORUM_VIEW_PERCENT'			=> round($forum_goals_views_percent),
					'FORUM_VIEW_REST'				=> $forum_goals_views_rest,
				));
			}
	}
}